@@ -1,4 +1,3 @@
-from functools import total_ordering
 from io import BytesIO
 from pathlib import Path
 from typing import Any, Union
@@ -99,12 +98,3 @@ def resolve_dict_iterator(iterator: Any, nrows: int = None) -> tuple:
         ),
         array["flip"],
     )
-
-
-@total_ordering
-class NoneSorter:
-    def __gt__(self, other):
-        return True
-
-    def __eq__(self, other):
-        return self is other
